==> zio-aws-auditmanager_2.13-5.17.116.2-sources.jar: zio/aws/auditmanager/model/ListAssessmentFrameworksRequest.scala <==
package zio.aws.auditmanager.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.auditmanager.model.primitives.{MaxResults, Token}
import scala.jdk.CollectionConverters._
final case class ListAssessmentFrameworksRequest(
    frameworkType: zio.aws.auditmanager.model.FrameworkType,
    nextToken: Option[Token] = None,
    maxResults: Option[MaxResults] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.auditmanager.model.ListAssessmentFrameworksRequest = {
    import ListAssessmentFrameworksRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.auditmanager.model.ListAssessmentFrameworksRequest
      .builder()
      .frameworkType(frameworkType.unwrap)
      .optionallyWith(
        nextToken.map(value => Token.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly
      : zio.aws.auditmanager.model.ListAssessmentFrameworksRequest.ReadOnly =
    zio.aws.auditmanager.model.ListAssessmentFrameworksRequest
      .wrap(buildAwsValue())
}
object ListAssessmentFrameworksRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.auditmanager.model.ListAssessmentFrameworksRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.auditmanager.model.ListAssessmentFrameworksRequest =
      zio.aws.auditmanager.model.ListAssessmentFrameworksRequest(
        frameworkType,
        nextToken.map(value => value),
        maxResults.map(value => value)
      )
    def frameworkType: zio.aws.auditmanager.model.FrameworkType
    def nextToken: Option[Token]
    def maxResults: Option[MaxResults]
    def getFrameworkType
        : ZIO[Any, Nothing, zio.aws.auditmanager.model.FrameworkType] =
      ZIO.succeed(frameworkType)
    def getNextToken: ZIO[Any, AwsError, Token] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.auditmanager.model.ListAssessmentFrameworksRequest
  ) extends zio.aws.auditmanager.model.ListAssessmentFrameworksRequest.ReadOnly {
    override val frameworkType: zio.aws.auditmanager.model.FrameworkType =
      zio.aws.auditmanager.model.FrameworkType.wrap(impl.frameworkType())
    override val nextToken: Option[Token] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.auditmanager.model.primitives.Token(value))
    override val maxResults: Option[MaxResults] = scala
      .Option(impl.maxResults())
      .map(value => zio.aws.auditmanager.model.primitives.MaxResults(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.auditmanager.model.ListAssessmentFrameworksRequest
  ): zio.aws.auditmanager.model.ListAssessmentFrameworksRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-auditmanager_2.13-5.17.197.1-sources.jar: zio/aws/auditmanager/model/ListAssessmentFrameworksRequest.scala <==
package zio.aws.auditmanager.model
import zio.prelude.data.Optional
import zio.aws.auditmanager.model.primitives.{MaxResults, Token}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class ListAssessmentFrameworksRequest(
    frameworkType: zio.aws.auditmanager.model.FrameworkType,
    nextToken: Optional[Token] = Optional.Absent,
    maxResults: Optional[MaxResults] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.auditmanager.model.ListAssessmentFrameworksRequest = {
    import ListAssessmentFrameworksRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.auditmanager.model.ListAssessmentFrameworksRequest
      .builder()
      .frameworkType(frameworkType.unwrap)
      .optionallyWith(
        nextToken.map(value => Token.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly
      : zio.aws.auditmanager.model.ListAssessmentFrameworksRequest.ReadOnly =
    zio.aws.auditmanager.model.ListAssessmentFrameworksRequest
      .wrap(buildAwsValue())
}
object ListAssessmentFrameworksRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.auditmanager.model.ListAssessmentFrameworksRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.auditmanager.model.ListAssessmentFrameworksRequest =
      zio.aws.auditmanager.model.ListAssessmentFrameworksRequest(
        frameworkType,
        nextToken.map(value => value),
        maxResults.map(value => value)
      )
    def frameworkType: zio.aws.auditmanager.model.FrameworkType
    def nextToken: Optional[Token]
    def maxResults: Optional[MaxResults]
    def getFrameworkType
        : ZIO[Any, Nothing, zio.aws.auditmanager.model.FrameworkType] =
      ZIO.succeed(frameworkType)
    def getNextToken: ZIO[Any, AwsError, Token] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.auditmanager.model.ListAssessmentFrameworksRequest
  ) extends zio.aws.auditmanager.model.ListAssessmentFrameworksRequest.ReadOnly {
    override val frameworkType: zio.aws.auditmanager.model.FrameworkType =
      zio.aws.auditmanager.model.FrameworkType.wrap(impl.frameworkType())
    override val nextToken: Optional[Token] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.auditmanager.model.primitives.Token(value))
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.auditmanager.model.primitives.MaxResults(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.auditmanager.model.ListAssessmentFrameworksRequest
  ): zio.aws.auditmanager.model.ListAssessmentFrameworksRequest.ReadOnly =
    new Wrapper(impl)
}
